OpenSSL error queue — Error, ErrorStack, ErrState (OpenSSL 3.2+).
Every OpenSSL operation that can fail pushes one or more records onto a
thread-local error queue. ErrorStack::drain() pops the entire queue and
returns it as a Vec<Error>. Every public function in this crate that can
fail returns Result<T, ErrorStack>.
Structs
- Error
- A single record from the OpenSSL error queue.
- Error
Stack - A snapshot of all records that were on the thread-local OpenSSL error queue.