BorrowedOcspSingleResp

Struct BorrowedOcspSingleResp 

pub struct BorrowedOcspSingleResp<'a> { /* private fields */ }
A borrowed OCSP_SINGLERESP* whose lifetime is tied to its parent OcspBasicResp.

Obtained from OcspBasicResp::get_response. Does not free the underlying pointer on drop — the pointer is owned by the OCSP_BASICRESP and freed when the OcspBasicResp is dropped.

Implementations

Source

impl BorrowedOcspSingleResp<'_>

pub fn status(&self) -> Result<SingleRespStatus, ErrorStack>

Extract the revocation status from this SingleResponse entry.

Calls OCSP_single_get0_status to retrieve the certificate status, optional revocation reason, and the thisUpdate/nextUpdate/ revocationTime timestamps.

Errors

Returns Err if OpenSSL returns an unrecognised status code (< 0).