SignatureInfo

Struct SignatureInfo 

pub struct SignatureInfo {
    pub md_nid: i32,
    pub pk_nid: i32,
    pub security_bits: i32,
}
Decoded signature algorithm metadata from an X509 certificate.

Returned by X509::signature_info.

Fields

md_nid: i32

NID of the digest algorithm used in the signature.

0 (NID_undef) for algorithms that do not use a separate pre-hash step, such as Ed25519 and ML-DSA.

pk_nid: i32

NID of the public-key algorithm used in the signature.

security_bits: i32

Estimated security strength in bits (e.g. 128 for AES-128-equivalent).