FIPS provider helpers.
is_running is always available — it uses the public
OSSL_PROVIDER_available API and requires no special feature flag.
It is the only function needed by ordinary code that runs in FIPS mode
but does not implement a FIPS provider itself.
Items under #[cfg(feature = "fips-provider")] are only compiled when
the fips-provider cargo feature is enabled. They require non-public
OpenSSL headers (vtable access, prov_ctx helpers, ossl_prov_is_running,
etc.) and are only meaningful when you are implementing a FIPS provider.
Functions
- is_
running - Returns
trueif the FIPS provider is loaded and available in the given library context.