pub struct Provider { /* private fields */ }Expand description
A loaded OpenSSL provider (OSSL_PROVIDER*).
The provider remains loaded until this value is dropped. Keep it alive for
the lifetime of any algorithm descriptors that use the associated LibCtx.